run_analysis

Function run_analysis 

pub fn run_analysis(
    analyzer: &dyn LanguageAnalyzer,
    root: &Path,
    format: OutputFormat,
    overrides: &CliOverrides,
) -> CliResult<AnalysisOutput>
Scan files, run the analysis pipeline, and return the output.

Warnings are stored in AnalysisOutput::result but not printed; the caller is responsible for writing them to stderr.