AnalysisConfig

Struct AnalysisConfig 

pub struct AnalysisConfig {
    pub min_nodes: usize,
    pub min_lines: usize,
}
The subset of configuration relevant to language-specific parsing.

Fields

min_nodes: usize

Minimum number of AST nodes for a code unit to be analyzed.

min_lines: usize

Minimum number of source lines for a code unit to be analyzed.