Config

Struct Config 

pub struct Config {
    pub min_nodes: usize,
    pub similarity_threshold: f64,
    pub exclude: Vec<String>,
    pub max_exact_duplicates: Option<usize>,
    pub max_near_duplicates: Option<usize>,
    pub max_exact_percent: Option<f64>,
    pub max_near_percent: Option<f64>,
    pub min_lines: usize,
    pub exclude_tests: bool,
    pub sub_function: bool,
    pub min_sub_nodes: usize,
    pub root: PathBuf,
}
Configuration for cargo-dupes analysis.

Fields

min_nodes: usize

Minimum number of AST nodes for a code unit to be analyzed.

similarity_threshold: f64

Similarity threshold for near-duplicates (0.0 to 1.0).

exclude: Vec<String>

Path patterns to exclude from scanning.

max_exact_duplicates: Option<usize>

Exit code threshold: fail if exact duplicate count exceeds this.

max_near_duplicates: Option<usize>

Exit code threshold: fail if near duplicate count exceeds this.

max_exact_percent: Option<f64>

Exit code threshold: fail if exact duplicate percentage exceeds this.

max_near_percent: Option<f64>

Exit code threshold: fail if near duplicate percentage exceeds this.

min_lines: usize

Minimum number of source lines for a code unit to be analyzed.

exclude_tests: bool

Exclude test code (#test functions and #[cfg(test)] modules).

sub_function: bool

Enable sub-function duplicate detection.

min_sub_nodes: usize

Minimum number of AST nodes for a sub-function unit to be analyzed.

root: PathBuf

Root path to analyze.

Implementations

Source

impl Config

pub const fn analysis_config(&self) -> AnalysisConfig

Extract the parsing-relevant subset of the configuration.

pub fn load(root: &Path) -> Self

Load config with the following precedence:

  1. CLI overrides (applied by the caller after this method)
  2. dupes.toml in the project root
  3. [package.metadata.dupes] in Cargo.toml
  4. Defaults