pub fn count_nodes(node: &NormalizedNode) -> usizeExpand description
Count the number of nodes in a normalized tree. None sentinel nodes are not counted.
pub fn count_nodes(node: &NormalizedNode) -> usizeCount the number of nodes in a normalized tree. None sentinel nodes are not counted.